This is a bundled copy of the MIT-licensed `matplotlib-label-lines`, which lives here: https://github.com/cphyc/matplotlib-label-lines.

This is bundled 

a) for convenience, 

b) because the PyPI package name for the official package does not match the import name, which is tedious to look up, and 

c) becausee the functionality is simple enough that it makes sense to version-lock it.